var indexSectionsWithContent =
{
  0: "abcdfghiloprst",
  1: "abcdhiloprst",
  2: "i",
  3: "afgiors",
  4: "cdfilr"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Pages"
};

